#===============================================================================
#. Título: Inferência Estatística - Origem distribuição t de Student
#. Autor : José Cláudio Faria/UESC/DCET
# Data  : 2023-01-14 12:22:06
#===============================================================================
# Objetivos gerais
#===============================================================================
# a) Apresentar os recursos básicos do R para a IE;
# b) Fundamentar o mestrando nos mecanismos básicos da IE.
#===============================================================================
# Objetivos específicos
#===============================================================================
# a) Gerar uma população normal (parâmetros definidos pelo usuário);
# b) Amostrar repetidamente a população (definido pelo usuário);
# c) Estimar o valor t a partir de cada amostra;
# d) Plotar o histograma dos valores tcal, que deve ser semelhante a função t
#    (parâmetros definidos pelo usuário) se o número de
#    repetições do processo for suficiente para se aproximar do limite;
# e) Sobrepor ao histograma a função densidade de probabilidade específica.
#===============================================================================

#.. ___Ini opções___
Mu   <-      40  # M pop
Sig  <-       5  # DP pop
n    <-       6  # Tamanho da amostra
nsim <-     1e4  # Número de simulações
p    <-  10/100  # Probabilidade adotada na inferência
#.. ___Fim opções___

#.. Bootstrap para calcular o vetor dos valores t
m <- matrix(rnorm(n * nsim,
                  Mu,
                  Sig),
            nsim,
            n)

#... Se Sigma for estimado a partir da amostra
t <- apply(m,
           1, #aplica nas linhas
           function(x) (mean(x) - Mu)/(sd(x)/sqrt(n)))

#... Se Sigma for conhecido
#t <- apply(m,
#           1, #aplica nas linhas
#           function(x) (mean(x) - Mu)/(Sig/sqrt(n)))

#.. Plotar o histograma dos valores t observados
x11(w=8.5, h=6.5)
par(mfrow=c(2, 1))

hist(t,
     xlim=c(-10, 10),
     main="Histograma",
     breaks=200,
     col="lightgray",
     xlab='t', 
     ylab="Fi",
     font.lab=2, 
     font=2)

hist(t,
     probability=T,
     xlim=c(-10, 10),
     ylim=c(0, 0.5),
     main='F.D.P e Histograma',
     breaks=200,
     col='lightgray',
     xlab='t', 
     ylab='f(t)',
     font.lab=2, 
     font=2)

#.. Adicionar a curva teórica dos valores t
# x = t
curve(dt(x, df=n-1), add=T, col="red", lwd=2, n=1e3)

#.. adicionar os limites para a inferência
qtl <- qt(p/2, df=n-1, lower.tail=T)
qtu <- qt(p/2, df=n-1, lower.tail=F)

segments(qtl, -1, qtl, 0.4, lwd=1)
segments(qtu, -1, qtu, 0.4, lwd=1)

text(qtl, 0.45,  round(qtl, 2))
text(qtu, 0.45,  round(qtu, 2))

text(-5, 0.45,  'RRHo', col='red')
text(-5, 0.40,  paste(100 * p/2, '%', sep=''), cex=.9, col='red')

text( 5, 0.45,  'RRHo', col='red')
text( 5, 0.40,  paste(100 * p/2, '%', sep=''), cex=.9, col='red')

text( 0, 0.45, 'RAHo', col='darkgreen')

text( 8, 0.3,  'H0: t=0', pos=4)
text( 8, 0.2,  'H1: t != 0', pos=4)

text(-9, 0.2,  'Curva teórica t', pos=4, col="red", cex=0.9)
text(-9, 0.3,  'Curva teórica normal reduzida', pos=4, col="blue", cex=0.9)

#.. Adicionar a curva teórica normal reduzida
curve(dnorm(x, mean=0, sd=1), add=T, col="blue", lwd=1, n=1e3)
