#===============================================================================
#. Ttulo: Inferncia Estatstica - Intervalo de Confiana para a Mdia
#. Autor : Jos Cludio Faria/UESC/DCET
# Data  : 2023-01-14 12:22:26
#===============================================================================
# Objetivos gerais
#===============================================================================
# a) Apresentar os recursos bsicos do R para a IE;
# b) Fundamentar o mestrando nos mecanismos bsicos da IE.
#===============================================================================
# Objetivos especficos
#===============================================================================
# a) Possibilitar o entendimento dos mecanismos de tomada de deciso em situao
#    de incerteza (inferncia) cercando o parmetro populacional desconhecido.
# b) Determinar o intervalo de confiana para a mdia populacional
#===============================================================================

#.. ___Ini opes___
#... parmetros da populao
Mu  <-  10  # mdia
Sig <-   1  # desvio padro
N   <- 1e4  # tamanho

#... tamanho das amostras, erro e quantidade de repeties do processo inferencial
n1 <- 20  # tamanhos da amostras
n2 <- 20

erro_1 <- 90/100  # erros adotado
erro_2 <- 99/100

r <- 100          # nmero de repeties do processo inferencial
#.. ___Fim opes___

vic_1 <- numeric() # vetor de armazenamento do intervalo de confiana
vic_2 <- numeric()

pop <- rnorm(N,
             Mu,
             Sig) # gera populao

#.. Loop para amostragem sequncial
for (i in 1:r) {
  amo1 <- sample(pop,
                 n1,
                 r=TRUE)                               # retira amostra de tamanho n de pop com reposio
  vic_1 <- cbind(vic_1,
                 t.test(amo1,
                        conf.level=erro_1)$conf.int)  # calcula o IC(M) (5% de erro) do vetor 'amo' e armazena na matriz 'vic'

  amo2 <- sample(pop,
                 n2,
                 r=TRUE) # retira amostra de tamanho n de pop com reposio
  vic_2 <- cbind(vic_2,
                 t.test(amo2,
                        conf.level=erro_2)$conf.int)  # calcula o IC(M) (5% de erro) do
}

# edit(t.test(amo1))     # observar opcionalmente o objeto denominado t.test(amo)
# is.list(t.test(amo1))  # verificar a natureza do objeto 't.test(amo)'

# vic_1 # visualizar objeto 'vic'

# Se o valor mnimo do intervalo estimado  menor que Mu (min < Mu),
# ou se o valor mximo do intervalo estimado  maior que Mu (max > Mu),
# obviamente, a mdia (M=Mu), no est contida no intervalo.
errou_1 <- apply(vic_1,
                 2,
                 min) > Mu | apply(vic_1,
                                   2,
                                   max) < Mu

errou_2 <- apply(vic_2,
                 2,
                 min) > Mu | apply(vic_2,
                                   2,
                                   max) < Mu

#.. Plotar as mdias de cada coluna de v (cada amostra)
par(mfrow=c(2,1))		# Divide o output grfico em 2 linhas e uma coluna

plot(apply(vic_1,
           2,
           mean),
     ylim = c(8.5, 11.5),
     ylab='Intervalo de confiana', 
     xlab='',
     pch=21, 
     col='brown', 
     bg='orange',
     main=paste0('Intervalos equivocados: ',
                 length(errou_1[errou_1 == TRUE]))
)

# Exemplo da mdia da primeira coluna de 'v' (primeira amostra)
# (vic_1[1,1] + vic_1[2,1]) / 2
# apply(vic_1,
#       2, 
#       mean) # digitar ?apply para verificar a funo apply

# Verificar se a mdia populacional (M = Mu) est (c[i]=FALSE),
# ou no (c[i]=TRUE), contida no intervalo de confiana estimado:

# obs: |  igual a OR (ou)
# digite ?'|' para ver os operadores lgicos do R

#.. Plotar a linha da mdia populacional conhecida (M=Mu)
abline(Mu, 0) # intercepto e declividade da reta

#.. Plotar os segmentos de reta correspondentes aos intervalos de confiana
segments(1:r,
         vic_1[1,],
         1:r,
         vic_1[2,],
         col=c(par('fg'), 'red')[errou_1 + 1],
         lwd=1.5)

plot(apply(vic_2,
           2,
           mean),
     ylim = c(8.5, 11.5),
     ylab='Intervalo de confiana', 
     xlab='repetio',
     pch=21, 
     col='brown', 
     bg='tomato',
     main=paste0('Intervalos equivocados: ',
                 length(errou_2[errou_2 == TRUE]))
)

# Exemplo da mdia da primeira coluna de 'v' (primeira amostra)
# (vic_2[1,1] + vic_2[2,1]) / 2
# apply(vic_2,
#       2, 
#       mean) # digitar ?apply para verificar a funo apply

# Verificar se a mdia populacional (M=Mu) est (c[i]=FALSE),
# ou no (c[i]=TRUE), contida no intervalo de confiana estimado:

# obs: |  igual a OR (ou)
# digite ?'|' para ver os operadores lgicos do R

#.. Plotar a linha da mdia populacional conhecida (M=Mu)
abline(Mu, 0) # intercepto e declividade da reta

#.. plotar os segmentos de reta correspondentes aos intervalos de confiana
segments(1:r,
         vic_2[1,],
         1:r,
         vic_2[2,],
         col=c(par('fg'), 'red')[errou_2 + 1],
         lwd=1.5)

#.. Contagme dos erros na inferncia
cat(paste0('Erros_1: ',
           length(errou_1[errou_1 == TRUE])),
    '\n')

cat(paste0('Erros_2: ',
           length(errou_2[errou_2 == TRUE])),
    '\n')
